@@ -4,7 +4,7 @@ test_that("not_null returns FALSE if value is NULL", {
 
 test_that("not_null returns TRUE if value is not NULL", {
   for_all(
-    a = any_vector(),
-    property = \(a) not_null(a) |> expect_true()
+    a = anything(),
+    property = \(a) (is.null(a) || not_null(a)) |> expect_true()
   )
 })
